/*
 * This file was generated automatically by xsubpp version 1.9508 from the
 * contents of MediaWiki.xs. Do not edit this file, edit MediaWiki.xs instead.
 *
 *	ANY CHANGES MADE HERE WILL BE LOST!
 *
 */

#line 1 "MediaWiki.xs"
#include "EXTERN.h"
#include "perl.h"
#include "XSUB.h"

#include "ppport.h"


#line 18 "MediaWiki.c"
#ifdef __cplusplus
extern "C"
#endif
XS(boot_CMS__MediaWiki); /* prototype to pass -Wmissing-prototypes */
XS(boot_CMS__MediaWiki)
{
    dXSARGS;

    XS_VERSION_BOOTCHECK ;

    XSRETURN_YES;
}

